import * as BUI from "@thatopen/ui";
import * as THREE from "three";
/**
 * Interface representing the state of the MaterialsList component. It contains an array of THREE.Material objects.
 */
export interface MaterialsListUIState {
    /**
     * An array of THREE.Material objects.
     */
    materials: THREE.Material[];
}
/**
 * A function that generates a template for the MaterialsList component. This template is a function that takes a MaterialsListUIState object as a parameter and returns a HTMLDivElement.
 *
 * @param state - An object representing the state of the MaterialsList component.
 * @returns A HTMLDivElement representing the template for the MaterialsList component.
 */
export declare const materialsListTemplate: (state: MaterialsListUIState) => BUI.TemplateResult<1>;
/**
 * A function that creates a MaterialsList component. This component displays a dropdown menu for selecting a material from a list of THREE.Material objects. It also shows a section for editing the properties of the selected material.
 *
 * @param materials - An array of THREE.Material objects to populate the dropdown menu.
 * @returns A BUI.Component representing the MaterialsList component.
 */
export declare const materialsList: (materials: THREE.Material[]) => [element: HTMLDivElement, update: BUI.UpdateFunction<MaterialsListUIState>, currentState: () => MaterialsListUIState];
